/* Created by Andrés Gvirtz on January 23 2017, Last edit on June 3 2018

*----------------------------------------------------------------------------------

Content: 


		(1) Save historical county population data in STATA format
		(2) Aggregate population data to CZ level
				2.1) For all data
				2.2) For union data
		(3) Consolidate data sets
				3.1) For all data
				3.2) For union data
				
*/	
	
* Adjust pathway to your local folder	

	
	global input "~/Dropbox/EGP/Master_Crosswalk_2018/UserFiles_Website"
	set more off	
		

		
		
		
*----------------------------------------------------------------------------------		
*----------------- (1) Save historical county population data in STATA format
*----------------------------------------------------------------------------------

	foreach year of numlist 1790(10)2000{	
		import delimited "$input/Historical Population Data/`year'.csv", varnames(1) case(preserve) clear 
			keep YEAR STATENH COUNTYNH A00AA`year'
			capture destring YEAR STATENH COUNTYNH A00AA`year', replace
			rename STATENH fips_state
			rename COUNTYNH fips_county
			rename A00AA`year' POP_`year'  
			keep fips_state fips_county POP_`year' 			
		saveold "$input/Historical Population Data/POP_`year'.dta", replace
	}
	
	
*----------------------------------------------------------------------------------
*----------------- (2) Aggregate population data to CZ level --------------------------
*----------------------------------------------------------------------------------

* 2.1 [ALL DATA] Add crosswalks with NHGIS data 
	foreach year of numlist 1790(10)2000{	
		use "$input/Historical Population Data/POP_`year'.dta", clear
		
		merge 1:m fips_state fips_county using "$input/CrossWalkFiles/egp_cty`year'ctycz1990_cw.dta"
				drop _merge
				drop if icp_state == .
			*	 do "$output\20171014_Drop_nUnion"
				
			ds icp_state icp_county icp_state_1990 icp_county_1990 fips_state fips_county fips_state_1990 fips_county_1990 cz year, not
			local varlist2 `r(varlist)'
			
			foreach x of local varlist2 {
				replace `x'=`x'*weight
			}
			
			* Aggregate data at CZ level
			collapse(sum) `varlist2', by(cz)
			label variable cz "Commuting Zone (1990 definition)" 
			label variable POP_`year' "Population `year'" 

			replace POP_`year' = . if POP_`year' == 0
			
				keep cz POP_`year' weight	
		saveold "$input/Historical Population Data/EGP_POP_`year'.dta", replace
	}
	
* 2.2) [UNION] Add crosswalks with NHGIS data 
	foreach year of numlist 1790(10)2000{	
		use "$input/Historical Population Data/POP_`year'.dta", clear
		
		merge 1:m fips_state fips_county using "$input/CrossWalkFiles/egp_cty`year'ctycz1990_cw.dta"
				drop _merge
				drop if icp_state == .
				 do "$input/EGP_Drop_nonUnion.do"
				
			ds icp_state icp_county icp_state_1990 icp_county_1990 fips_state fips_county fips_state_1990 fips_county_1990 cz year, not
			local varlist2 `r(varlist)'
			
			foreach x of local varlist2 {
				replace `x'=`x'*weight
			}
			
			* Aggregate data at CZ level
			collapse(sum) `varlist2', by(cz)
			label variable cz "Commuting Zone (1990 definition)" 
			label variable POP_`year' "Population `year'" 

			replace POP_`year' = . if POP_`year' == 0
			
				keep cz POP_`year' weight
		saveold "$input/Historical Population Data/EGP_POP_UNION_`year'.dta", replace
	}	
	
	
	
*-------------------------------------------------------------------------------	
*----------------- (3) Consolidate all data sets -------------------------------
*-------------------------------------------------------------------------------

* 3.1) [ALL DATA] Consolidate data sets ----------------------------------------
	use "$input/Historical Population Data/EGP_POP_1790.dta", clear
		foreach year of numlist 1800(10)2000{	
		merge 1:1 cz using "$input/Historical Population Data/EGP_POP_`year'"
			drop weight
			drop _merge
	 }
	 
	saveold "$input/Historical Population Data/EGP_POP_ALL_YEARS.dta", replace
	 
* 3.2 [UNION DATA] Consolidate data sets ---------------------------------------
	use "$input/Historical Population Data/EGP_POP_UNION_1790.dta", clear
		foreach year of numlist 1800(10)2000{	
		merge 1:1 cz using "$input/Historical Population Data/EGP_POP_UNION_`year'"
			drop weight
			drop _merge
	 }
	 
	saveold "$input/Historical Population Data/EGP_POP_UNION_ALL_YEARS.dta", replace
	
	
*-------------------------------------------------------------------------------	
*--------------------- (4) Clean workspace -------------------------------------
*-------------------------------------------------------------------------------	

	foreach year of numlist 1790(10)2000{
	
	rm "$input/Historical Population Data/EGP_POP_`year'.dta"
	rm "$input/Historical Population Data/EGP_POP_UNION_`year'.dta"
	rm "$input/Historical Population Data/POP_`year'.dta"
	
	
	}

